#hwdbfilterlist-search {
    margin-top: 1em;
}

.act-filter-tag {
    background-color: #00B1B1;
    border-radius: 4px;
    color: white;
}

.act-filter-field {
    margin: 0 0.1em 0 0.5em;
}

.act-filter-val {
    font-weight: 600;
}

.act-filter-remove button {
    background-color: inherit;
    border: none;
}